@@ -1,4 +1,5 @@
-from ..base.model import SerializeFormat
+from ..base.model import SerializeFormat, Model
+from ..core.class_ import Class
 from ..core.function import Function
 from ..core.object import Objects, Object
 from ..utils.error import Error
@@ -11,10 +12,10 @@ class SerializerBase(object):
 
     def __init__(self):
         self.serialize_protocol = {}
-        self.model = None
-        self.current_class = None
+        self.model: Model or None = None
+        self.current_class: Class or None = None
 
-    def generate_methods(self, model):
+    def generate_methods(self, model: Model):
         self.model = model
 
         formats = SerializeFormat.get_all()
@@ -23,6 +24,8 @@ class SerializerBase(object):
                 model.parser.load_default_serialize_protocol(self.get_protocol(string_format))
                 self.serialize_protocol = model.serialize_protocol
                 for cls in model.classes:
+                    if cls.type == 'enum':
+                        continue
                     self.current_class = cls
                     self.create_serialization_function(cls, SERIALIZATION, string_format)
                     self.create_serialization_function(cls, DESERIALIZATION, string_format)
@@ -40,7 +43,7 @@ class SerializerBase(object):
 
         method.args.append(self.get_serialization_function_args(serialize_type, serialize_format))
         body = ''
-        if cls.superclasses:
+        if cls.superclasses and cls.type != 'enum' and cls.superclasses[0].type != 'enum':
             parent_call = self.get_parent_serialize_format()
             body += parent_call.format(cls.superclasses[0].name, method.name, method.args[0][0])
         for obj in cls.members:
